<?php

namespace BooklyPro\Frontend\Modules\SearchForm;

use Bookly\Lib as BooklyLib;
use Bookly\Backend\Modules;

/**
 * Class ShortCode
 *
 * @package BooklyPro\Frontend\Modules\SearchForm
 */
class ShortCode extends BooklyLib\Base\Component
{
    /**
     * Init component.
     */
    public static function init()
    {
        // Register short code.
        add_shortcode( 'bookly-search-form', array( __CLASS__, 'render' ) );

        // Assets.
        add_action( 'wp_enqueue_scripts', array( __CLASS__, 'linkStyles' ) );
        add_action( 'wp_enqueue_scripts', array( __CLASS__, 'linkScripts' ) );
    }

    /**
     * Link styles.
     */
    public static function linkStyles()
    {
        if ( BooklyLib\Utils\Common::postsHaveShortCode( 'bookly-search-form' ) ) {
            self::enqueueStyles( array(
                'frontend' => array(
                    '/css/bootstrap.bundle.min.css' => array(),
                    '/css/bootstrap-icons.css' => array(),
                ),
            ) );
        }
    }

    /**
     * Link scripts.
     */
    public static function linkScripts()
    {
        if ( BooklyLib\Utils\Common::postsHaveShortCode( 'bookly-search-form' ) ) {

            $tel_input_enabled = get_option( 'bookly_cst_phone_default_country' ) !== 'disabled';

            self::enqueueScripts( array(
                'frontend' => array(
                    'js/bootstrap.bundle.min.js' => array( 'jquery' ),
                ),
                'module' => array(
                    'js/search-form.js' => array( 'bookly-bootstrap.bundle.min.js' ),
                ),
            ) );
            if ( $tel_input_enabled ) {
                self::enqueueStyles( array(
                    'frontend' => array( 'css/intlTelInput.css' ),
                ) );
                self::enqueueScripts( array(
                    'bookly' => array( 'frontend/resources/js/intlTelInput.min.js' => array( 'jquery' ) ),
                ) );
            }

            wp_localize_script( 'bookly-search-form.js', 'BooklyL10nSearchForm', array(
                'l10n' => array(
                    'staff' => __( 'Staff', 'bookly' ),
                    'service' => __( 'Service', 'bookly' ),
                    'location' => __( 'Location', 'bookly' ),
                    'date' => __( 'Date', 'bookly' ),
                    'price' => __( 'Price', 'bookly' ),
                    'back' => __( 'Back', 'bookly' ),
                    'select_service' => __( 'Select service', 'bookly' ),
                    'any' => __( 'Any', 'bookly' ),
                    'book_now' => __( 'Book now', 'bookly' ),
                    'book_more' => __( 'Book more', 'bookly' ),
                    'close' => __( 'Close', 'bookly' ),
                    'first_name' => __( 'First name', 'bookly' ),
                    'last_name' => __( 'Last name', 'bookly' ),
                    'email' => __( 'Email', 'bookly' ),
                    'phone' => __( 'Phone', 'bookly' ),
                    'no_slots' => __( 'No time slots available', 'bookly' ),
                    'no_results' => __( 'No results found', 'bookly' ),
                    'nop' => __( 'Number of persons', 'bookly' ),
                    'units' => __( 'Units', 'bookly' ),
                    'notices' => array(
                        'first_name' => __( 'Required', 'bookly' ),
                        'last_name' => __( 'Required', 'bookly' ),
                        'email' => __( 'Required', 'bookly' ),
                        'phone' => __( 'Required', 'bookly' ),
                        'slots' => __( 'Slot already booked', 'bookly' ),
                    ),
                ),
                'datePicker' => BooklyLib\Utils\DateTime::datePickerOptions(),
                'maxDaysForBooking' => BooklyLib\Config::getMaximumAvailableDaysForBooking(),
                'casest' => BooklyLib\Config::getCaSeSt(),
                'intlTelInput' => array(
                    'enabled' => $tel_input_enabled,
                    'utils' => plugins_url( 'intlTelInput.utils.js', BooklyLib\Plugin::getDirectory() . '/frontend/resources/js/intlTelInput.utils.js' ),
                    'country' => get_option( 'bookly_cst_phone_default_country' ),
                ),
            ) );
        }
    }

    /**
     * Render shortcode.
     *
     * @param array $attr
     * @return string
     */
    public static function render( $attr )
    {
        global $sitepress;

        // Disable caching.
        BooklyLib\Utils\Common::noCache();

        // Prepare URL for AJAX requests.
        $ajaxurl = admin_url( 'admin-ajax.php' );

        // Support WPML.
        if ( $sitepress instanceof \SitePress ) {
            $ajaxurl = add_query_arg( array( 'lang' => $sitepress->get_current_language() ), $ajaxurl );
        }


        $form_id = uniqid( 'bookly-search-form-', false );

        return self::renderTemplate( 'short_code', compact( 'ajaxurl', 'form_id' ), false );
    }
}